/*
 *  
 *  Copyright (c) 2004 Steve Slaven, All Rights Reserved.
 *  
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA 02111-1307 USA
 *  
*/
/* This is a test search class to test various pathfinding algos */

package net.hoopajoo.cheeselab3;

import java.util.Date;
import java.sql.Connection;
import java.sql.DriverManager;

public class TestSearch {
    public static void main( String[] args ) {
        // Needs odd number of arguments (first 3 are required, rest are key/value config pairs)
        if( args.length < 3 || args.length % 2 == 0 ) {
            System.out.println( "Usage: test method startid endid [opt value] [opt value]" );
            System.exit( 1 );
        }

        String method = args[ 0 ];
        int startid = Integer.parseInt( args[ 1 ] );
        int endid = Integer.parseInt( args[ 2 ] );

        Connection db = null;

        System.out.println( "Connecting to database..." );
        try {
            Class.forName( "org.apache.derby.jdbc.EmbeddedDriver" );
            db = DriverManager.getConnection( "jdbc:derby:cheesedb" );
        } catch( Exception e ) {
            System.out.println( "Unable to load database: " + e );
            System.exit( 1 );
        }

        System.out.println( "Creating pathfinder...." );
        PathFinder p = null;
        if( method.equals( "bfs" ) ) {
            p = new PathFinderBFS();
        } else {
            p = new PathFinder();
        }

        System.out.println( "Path finder class is: " + p.getClass() );
        p.set_db( db );

        // Parse config
        for( int optidx = 3; optidx < args.length; optidx += 2 )
            p.set_option( args[ optidx ], args[ optidx + 1 ] );

        Date start = new Date();
        String dirs = p.find_path( startid, endid );
        Date end = new Date();

        if( dirs == null ) {
            System.out.println( "Error finding path: " + p.get_error() );
        } else {
            System.out.println( "Steps: " + dirs.length() );
            System.out.println( "Path: " + dirs );
        }

        long rdiff = end.getTime() - start.getTime();
        double secs = (double)rdiff / 1000;
        System.out.println( "Path finding time: " + rdiff + "ms (" + secs + " secs)" );
        System.out.println( "Stats:" );
        p.print_stats();
    }
}
